@@ -14,8 +14,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * License along with this library. If not, see
+ * <http://www.gnu.org/licenses/>.
  *
  * Author: Daniel P. Berrange <berrange@redhat.com>
  */
@@ -31,11 +31,33 @@ do_connection_open(GObject *source,
 {
     GVirConnection *conn = GVIR_CONNECTION(source);
     GError *err = NULL;
+    gchar *hv_name = NULL;
+    gulong hv_version = 0;
+    guint major, minor, micro;
 
     if (!gvir_connection_open_finish(conn, res, &err)) {
         g_error("%s", err->message);
     }
+
     g_print("Connected to libvirt\n");
+
+    if (!(hv_name = gvir_connection_get_hypervisor_name(conn, &err))) {
+        g_error("%s", err->message);
+    }
+
+    g_print("Hypervisor name: %s\n", hv_name);
+
+    if (!(hv_version = gvir_connection_get_version(conn, &err))) {
+        g_error("%s", err->message);
+    }
+
+    major = hv_version / 1000000;
+    hv_version %= 1000000;
+    minor = hv_version / 1000;
+    micro = hv_version % 1000;
+    g_print("Hypervisor version: %u.%u.%u\n", major, minor, micro);
+
+    g_free(hv_name);
     g_object_unref(conn);
 }
 
