@@ -42,11 +42,11 @@ static void gvir_config_interface_class_init(GVirConfigInterfaceClass *klass)
 }
 
 
-static void gvir_config_interface_init(GVirConfigInterface *conn)
+static void gvir_config_interface_init(GVirConfigInterface *iface)
 {
-    g_debug("Init GVirConfigInterface=%p", conn);
+    g_debug("Init GVirConfigInterface=%p", iface);
 
-    conn->priv = GVIR_CONFIG_INTERFACE_GET_PRIVATE(conn);
+    iface->priv = GVIR_CONFIG_INTERFACE_GET_PRIVATE(iface);
 }
 
 
