@@ -99,3 +99,16 @@ void gvir_config_storage_vol_target_set_permissions(GVirConfigStorageVolTarget *
                                       "permissions",
                                       GVIR_CONFIG_OBJECT(perms));
 }
+
+/**
+ * gvir_config_storage_vol_target_set_compat:
+ * @compat: (allow-none):
+ */
+void gvir_config_storage_vol_target_set_compat(GVirConfigStorageVolTarget *target,
+                                               const char *compat)
+{
+    g_return_if_fail(GVIR_CONFIG_IS_STORAGE_VOL_TARGET(target));
+
+    gvir_config_object_set_node_content(GVIR_CONFIG_OBJECT(target),
+                                        "compat", compat);
+}
