@@ -44,11 +44,11 @@ static void gvir_config_storage_vol_class_init(GVirConfigStorageVolClass *klass)
 }
 
 
-static void gvir_config_storage_vol_init(GVirConfigStorageVol *conn)
+static void gvir_config_storage_vol_init(GVirConfigStorageVol *vol)
 {
-    g_debug("Init GVirConfigStorageVol=%p", conn);
+    g_debug("Init GVirConfigStorageVol=%p", vol);
 
-    conn->priv = GVIR_CONFIG_STORAGE_VOL_GET_PRIVATE(conn);
+    vol->priv = GVIR_CONFIG_STORAGE_VOL_GET_PRIVATE(vol);
 }
 
 
