@@ -23,8 +23,12 @@
 
 #include <config.h>
 
+#include <glib.h>
 #include <libvirt/virterror.h>
 #include <string.h>
+#if !defined(HAVE_VIR_DOMAIN_OPEN_GRAPHICS_FD) && !defined(G_OS_WIN32)
+#include <sys/socket.h>
+#endif
 
 #include "libvirt-glib/libvirt-glib.h"
 #include "libvirt-gobject/libvirt-gobject.h"
@@ -1221,6 +1225,86 @@ cleanup:
     return ret;
 }
 
+/**
+ * gvir_domain_open_graphics_fd:
+ * @dom: the domain
+ * @idx: the graphics index
+ * @flags: extra flags, currently unused
+ *
+ * This will create a socket pair connected to the graphics backend of @dom. One
+ * end of the socket will be returned on success, and the other end is handed to
+ * the hypervisor. If @dom has multiple graphics backends configured, then @idx
+ * will determine which one is opened, starting from @idx 0.
+ *
+ * Returns: An fd on success, -1 on failure.
+ *
+ * Since: 0.2.0
+ */
+#if defined(HAVE_VIR_DOMAIN_OPEN_GRAPHICS_FD) || !defined(G_OS_WIN32)
+int gvir_domain_open_graphics_fd(GVirDomain *dom,
+                                 guint idx,
+                                 unsigned int flags,
+                                 GError **err)
+{
+    GVirDomainPrivate *priv;
+    int ret = -1;
+#ifndef HAVE_VIR_DOMAIN_OPEN_GRAPHICS_FD
+    int pair[2];
+#endif
+
+    g_return_val_if_fail(GVIR_IS_DOMAIN(dom), -1);
+    g_return_val_if_fail(err == NULL || *err == NULL, -1);
+
+    priv = dom->priv;
+
+#ifdef HAVE_VIR_DOMAIN_OPEN_GRAPHICS_FD
+    ret = virDomainOpenGraphicsFD(priv->handle, idx, flags);
+    if (ret <= 0) {
+        gvir_set_error_literal(err, GVIR_DOMAIN_ERROR,
+                               0,
+                               "Unable to open graphics");
+        goto end;
+    }
+
+#else
+    if (socketpair(PF_UNIX, SOCK_STREAM, 0, pair) < 0) {
+        g_set_error_literal(err, GVIR_DOMAIN_ERROR,
+                            0,
+                            "Failed to create socket pair");
+        goto end;
+    }
+
+    if (virDomainOpenGraphics(priv->handle, idx, pair[0], flags) < 0) {
+        gvir_set_error_literal(err, GVIR_DOMAIN_ERROR,
+                               0,
+                               "Unable to open graphics");
+        close(pair[0]);
+        close(pair[1]);
+
+        goto end;
+    }
+    close(pair[0]);
+    ret = pair[1];
+#endif
+
+end:
+    return ret;
+}
+#else
+int gvir_domain_open_graphics_fd(GVirDomain *dom G_GNUC_UNUSED,
+                                 guint idx G_GNUC_UNUSED,
+                                 unsigned int flags G_GNUC_UNUSED,
+                                 GError **err)
+{
+    g_set_error_literal(err, GVIR_DOMAIN_ERROR,
+                        0,
+                        "Unable to create socketpair on this platform");
+    return -1;
+}
+#endif
+
+
+
 /**
  * gvir_domain_suspend:
  * @dom: the domain to suspend
@@ -1537,7 +1621,7 @@ gvir_domain_create_snapshot(GVirDomain *dom,
 static void _create_snapshot_async_thread(GTask *task,
                                           gpointer source_object,
                                           gpointer task_data,
-                                          GCancellable *cancellable)
+                                          GCancellable *cancellable G_GNUC_UNUSED)
 {
     GError *error = NULL;
     GVirDomainSnapshot *snapshot;
