@@ -29,6 +29,9 @@
 #include "libvirt-glib/libvirt-glib.h"
 #include "libvirt-gobject/libvirt-gobject.h"
 #include "libvirt-gobject-compat.h"
+#ifdef HAVE_VIR_NETWORK_GET_DHCP_LEASES
+#include "libvirt-gobject/libvirt-gobject-network-dhcp-lease-private.h"
+#endif /* HAVE_VIR_NETWORK_GET_DHCP_LEASES */
 
 #define GVIR_NETWORK_GET_PRIVATE(obj)                         \
         (G_TYPE_INSTANCE_GET_PRIVATE((obj), GVIR_TYPE_NETWORK, GVirNetworkPrivate))
@@ -62,8 +65,8 @@ static void gvir_network_get_property(GObject *object,
                                       GValue *value,
                                       GParamSpec *pspec)
 {
-    GVirNetwork *conn = GVIR_NETWORK(object);
-    GVirNetworkPrivate *priv = conn->priv;
+    GVirNetwork *network = GVIR_NETWORK(object);
+    GVirNetworkPrivate *priv = network->priv;
 
     switch (prop_id) {
     case PROP_HANDLE:
@@ -81,8 +84,8 @@ static void gvir_network_set_property(GObject *object,
                                       const GValue *value,
                                       GParamSpec *pspec)
 {
-    GVirNetwork *conn = GVIR_NETWORK(object);
-    GVirNetworkPrivate *priv = conn->priv;
+    GVirNetwork *network = GVIR_NETWORK(object);
+    GVirNetworkPrivate *priv = network->priv;
 
     switch (prop_id) {
     case PROP_HANDLE:
@@ -99,10 +102,10 @@ static void gvir_network_set_property(GObject *object,
 
 static void gvir_network_finalize(GObject *object)
 {
-    GVirNetwork *conn = GVIR_NETWORK(object);
-    GVirNetworkPrivate *priv = conn->priv;
+    GVirNetwork *network = GVIR_NETWORK(object);
+    GVirNetworkPrivate *priv = network->priv;
 
-    g_debug("Finalize GVirNetwork=%p", conn);
+    g_debug("Finalize GVirNetwork=%p", network);
 
     virNetworkFree(priv->handle);
 
@@ -145,11 +148,11 @@ static void gvir_network_class_init(GVirNetworkClass *klass)
 }
 
 
-static void gvir_network_init(GVirNetwork *conn)
+static void gvir_network_init(GVirNetwork *network)
 {
-    g_debug("Init GVirNetwork=%p", conn);
+    g_debug("Init GVirNetwork=%p", network);
 
-    conn->priv = GVIR_NETWORK_GET_PRIVATE(conn);
+    network->priv = GVIR_NETWORK_GET_PRIVATE(network);
 }
 
 typedef struct virNetwork GVirNetworkHandle;
@@ -224,3 +227,65 @@ GVirConfigNetwork *gvir_network_get_config(GVirNetwork *network,
     free(xml);
     return conf;
 }
+
+/**
+ * gvir_network_get_dhcp_leases:
+ * @network: the network
+ * @mac: (allow-none): The optional ASCII formatted MAC address of an interface
+ * @flags: placeholder for flags, must be 0
+ *
+ * @err: Place-holder for possible errors
+ *
+ * This function fetches leases info of guests in the specified network. If the
+ * optional parameter @mac is specified, the returned list will contain only
+ * lease info about a specific guest interface with @mac. There can be multiple
+ * leases for a single @mac because this API supports DHCPv6 too.
+ *
+ * Returns:  (element-type LibvirtGObject.NetworkDHCPLease) (transfer full): the
+ * list of network leases. Each object in the returned list should be unreffed
+ * with g_object_unref() and the list itself using g_list_free, when no longer
+ * needed.
+ */
+GList *gvir_network_get_dhcp_leases(GVirNetwork *network,
+                                    const char *mac G_GNUC_UNUSED,
+                                    guint flags,
+                                    GError **err)
+{
+#ifdef HAVE_VIR_NETWORK_GET_DHCP_LEASES
+    virNetworkDHCPLeasePtr *leases;
+    GList *ret = NULL;
+    int num_leases, i;
+#endif /* HAVE_VIR_NETWORK_GET_DHCP_LEASES */
+
+    g_return_val_if_fail(GVIR_IS_NETWORK(network), NULL);
+    g_return_val_if_fail(err == NULL || *err == NULL, NULL);
+    g_return_val_if_fail(flags == 0, NULL);
+
+#ifdef HAVE_VIR_NETWORK_GET_DHCP_LEASES
+    num_leases = virNetworkGetDHCPLeases(network->priv->handle, mac, &leases, flags);
+    if (num_leases < 0) {
+        gvir_set_error_literal(err, GVIR_NETWORK_ERROR,
+                               0,
+                               "Unable to get network DHCP leases");
+        return NULL;
+    }
+
+    if (num_leases == 0)
+        return NULL;
+
+    for (i = 0; i < num_leases; i++) {
+        GVirNetworkDHCPLease *lease;
+
+        lease = gvir_network_dhcp_lease_new(leases[i]);
+        ret = g_list_prepend(ret, lease);
+    }
+    free(leases);
+
+    return g_list_reverse(ret);
+#else /* HAVE_VIR_NETWORK_GET_DHCP_LEASES */
+    g_set_error_literal(err, GVIR_NETWORK_ERROR,
+                        0,
+                        "Unable to get network DHCP leases");
+    return NULL;
+#endif /* HAVE_VIR_NETWORK_GET_DHCP_LEASES */
+}
