@@ -27,6 +27,8 @@
 #include <libvirt/virterror.h>
 #include <string.h>
 
+#include <glib/gi18n-lib.h>
+
 #include "libvirt-glib/libvirt-glib.h"
 #include "libvirt-gobject/libvirt-gobject.h"
 #include "libvirt-gobject-compat.h"
@@ -100,17 +102,31 @@ static GOutputStream* gvir_stream_get_output_stream(GIOStream *io_stream)
 
 static gboolean gvir_stream_close(GIOStream *io_stream,
                                   GCancellable *cancellable,
-                                  G_GNUC_UNUSED GError **error)
+                                  GError **error)
 {
     GVirStream *self = GVIR_STREAM(io_stream);
+    GError *local_error = NULL;
+    gboolean i_ret = TRUE, o_ret = TRUE;
+
+    g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
 
     if (self->priv->input_stream)
-        g_input_stream_close(self->priv->input_stream, cancellable, NULL);
+        i_ret = g_input_stream_close(self->priv->input_stream, cancellable, &local_error);
+
+    if (local_error)
+        g_propagate_error(error, local_error);
 
     if (self->priv->output_stream)
-        g_output_stream_close(self->priv->output_stream, cancellable, NULL);
+        o_ret = g_output_stream_close(self->priv->output_stream, cancellable, &local_error);
 
-    return TRUE; /* FIXME: really close the stream? */
+    if (local_error) {
+        if (i_ret)
+            g_propagate_error(error, local_error);
+        else
+            g_error_free(local_error);
+    }
+
+    return (i_ret && o_ret);
 }
 
 
@@ -320,10 +336,10 @@ gssize gvir_stream_receive(GVirStream *self,
 
     if (got == -2) {  /* blocking */
         g_set_error_literal(error, G_IO_ERROR, G_IO_ERROR_WOULD_BLOCK,
-                            "virStreamRecv call would block");
+                            _("virStreamRecv call would block"));
     } else if (got < 0) {
         g_set_error(error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-                    "Got virStreamRecv error in %s", G_STRFUNC);
+                    _("Got virStreamRecv error in %s"), G_STRFUNC);
     }
 
     return got;
@@ -388,7 +404,7 @@ gvir_stream_receive_all(GVirStream *self,
     if (r < 0) {
         gvir_set_error_literal(error, GVIR_STREAM_ERROR,
                                0,
-                               "Unable to perform RecvAll");
+                               _("Unable to perform RecvAll"));
     }
 
     return r;
@@ -436,10 +452,10 @@ gssize gvir_stream_send(GVirStream *self,
 
     if (got == -2) {  /* blocking */
         g_set_error_literal(error, G_IO_ERROR, G_IO_ERROR_WOULD_BLOCK,
-                            "virStreamSend call would block");
+                            _("virStreamSend call would block"));
     } else if (got < 0) {
         g_set_error(error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
-                    "Got virStreamRecv error in %s", G_STRFUNC);
+                    _("Got virStreamRecv error in %s"), G_STRFUNC);
     }
 
     return got;
@@ -504,7 +520,7 @@ gvir_stream_send_all(GVirStream *self,
     if (r < 0) {
         gvir_set_error_literal(error, GVIR_STREAM_ERROR,
                                0,
-                               "Unable to perform SendAll");
+                               _("Unable to perform SendAll"));
     }
 
     return r;
